{ pkgs, config, inputs, ... }: {
  programs.zsh.enable = true;
  users.users.coded.shell = pkgs.zsh;

  home-manager.users.coded.home.packages = with pkgs; [
    bmon
    wget
    guake
  ];

  home-manager.users.coded.programs = {
    # ZSH
    zsh = {
      enable = true;
      enableAutosuggestions = true;
      enableCompletion = true;
      autocd = true;
      defaultKeymap = "emacs";

      shellAliases = {
        rebuild = "sudo nixos-rebuild switch --flake /home/coded/nixConfig/";
        "gr!" = "git review";
        clr = "clear";
        nh = "wget -O ~/Documents/hashCheck $1 | nix hash file ~/Documents/hashCheck";
        edit = "nvim";
        neovim = "nvim";
        v = "nvim";
      };

      dirHashes = { code = "$HOME/Documents/programming"; };

      history = { extended = true; };
      historySubstringSearch.enable = true;

      oh-my-zsh = {
        enable = true;
        plugins = [ "git" ];
      };
    };
    
    # Starship
    starship = {
      enable = true;
      settings = { format = "$all"; };
    };

    # Nix-index
    nix-index.enable = true;

    # thefuck
    thefuck = {
      enable = true;
      enableInstantMode = true;
    };
  };

  environment.pathsToLink =
    [ "/share/zsh" ]; # needed for completing system packages
}
